==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/outputs/IdentityResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties to configure Identity for Bring your Own Keys
 * @property principalId ObjectId from the KeyVault
 * @property tenantId TenantId from the KeyVault
 * @property type Type of managed service identity.
 * @property userAssignedIdentities Metadata of user assigned identity.
 */
public data class IdentityResponse(
    public val principalId: String,
    public val tenantId: String,
    public val type: String? = null,
    public val userAssignedIdentities: Map<String, List<UserAssignedIdentityResponse>>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbformysql.outputs.IdentityResponse):
            IdentityResponse = IdentityResponse(
            principalId = javaType.principalId(),
            tenantId = javaType.tenantId(),
            type = javaType.type().map({ args0 -> args0 }).orElse(null),
            userAssignedIdentities = javaType.userAssignedIdentities().map({ args0 ->
                args0.key.to(
                    args0.value.map({ args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.dbformysql.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                        })
                    }),
                )
            }).toMap(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/outputs/IdentityResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties to configure Identity for Bring your Own Keys
 * @property principalId ObjectId from the KeyVault
 * @property tenantId TenantId from the KeyVault
 * @property type Type of managed service identity.
 * @property userAssignedIdentities Metadata of user assigned identity.
 */
public data class IdentityResponse(
    public val principalId: String,
    public val tenantId: String,
    public val type: String? = null,
    public val userAssignedIdentities: Map<String, List<UserAssignedIdentityResponse>>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbformysql.outputs.IdentityResponse): IdentityResponse = IdentityResponse(
            principalId = javaType.principalId(),
            tenantId = javaType.tenantId(),
            type = javaType.type().map({ args0 -> args0 }).orElse(null),
            userAssignedIdentities = javaType.userAssignedIdentities().map({ args0 ->
                args0.key.to(
                    args0.value.map({ args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.dbformysql.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                        })
                    }),
                )
            }).toMap(),
        )
    }
}
